Index: /branches/2.4/INSTALL/expressoInstall.sh
===================================================================
--- /branches/2.4/INSTALL/expressoInstall.sh	(revision 6754)
+++ /branches/2.4/INSTALL/expressoInstall.sh	(revision 7116)
@@ -4,11 +4,11 @@
 #
 # Criado por William Fernando Merlotto <william@prognus.com.br>
-# Baseado no script original desenvolvido por JoÃ£o Alfredo Knopik Junior <jakjr@celepar.pr.gov.br>
-# com colaboraÃ§Ãµes de:
+# Baseado no script original desenvolvido por Joao Alfredo Knopik Junior <jakjr@celepar.pr.gov.br> 
+# com colaboracÃÂµes de: 
 #	"William Fernando Merlotto" <william@prognus.com.br>, para Debian, Ubuntu, Red Hat e CentOS
 #	"Gustavo Nakahara" <gustavonk@prognus.com.br>, para Debian, Ubuntu, Red Hat e CentOS
 #	"Rafael Cristaldo" <rafael@prognus.com.br>, para Debian, Ubuntu, Red Hat e CentOS
 #	"Alexandre Felipe Muller de Souza" <amuller@celepar.pr.gov.br>, para Debian
-#	"CÃ¡ssio Luiz" <cassiolp@cnpq.br>, para Red Hat e CentOS
+#   "Cassio Luiz" <cassiolp@cnpq.br>, para Red Hat e CentOS 
 # 	"M. Rodrigo Monteiro" <mrodrigom@gmail.com>, para Red Hat e CentOS
 #
@@ -24,5 +24,5 @@
 #################################################################################################
 
 # TODO: Internacionalizar o script de instalaÃ§Ã£o:
 # http://www.linuxquestions.org/questions/programming-9/bash-script-how-to-get-locale-translations-802726/
 # http://tldp.org/LDP/abs/html/localization.html
@@ -44,5 +44,5 @@
 
 # Verifica o usuario que esta executando o script
-# DEBUG: Comente esta linha para testar o script sem utilizar o usuÃ¡rio root.
+# DEBUG: Comente esta linha para testar o script sem utilizar o usuario root. 
 [ $UID != 0 ] && { echo "Este script deve ser executado como superusuario (root) ou com sudo"; exit 1; }
 
@@ -62,33 +62,33 @@
 	echo "Sistema operacional desconhecido ou incompativel com o instalador do Expresso Livre!"
 	echo "$OSSTR"
-	echo "Por favor, utilize uma distribuiÃ§Ã£o GNU/Linux compatÃ­vel: Debian 6.x, Ubuntu 11.10 ou CentOS/RedHat 6.x"
+	echo "Por favor, utilize uma distribuicao GNU/Linux compativel: Debian 6.x, Ubuntu 11.10 ou CentOS/RedHat 6.x" 
 	exit 1
 fi
 
 # Telas da instalacao
-BACKTITLE="InstalaÃ§Ã£o do ExpressoLivre versÃ£o $VERSAO"
+BACKTITLE="Instalacao do ExpressoLivre versao $VERSAO" 
 
 BACKTITLE="$BACKTITLE, para $INSTALL"
 
-# Inicializacao basica de instalacao, como atualizaÃ§Ã£o de repositÃ³rio e criaÃ§Ã£o de variÃ¡veis de ambiente
+# Inicializacao basica de instalacao, como atualizacao de repositorio e criacao de variaveis de ambiente 
 ini_$INSTALL
 
 INTRO='
-Bem-Vindo(a) a instalaÃ§Ã£o do ExpressoLivre!
+Bem-Vindo(a) a instalacao do ExpressoLivre! 
 
-O script de instalaÃ§Ã£o lhe permitirÃ¡ escolher entre instalar e configurar automaticamente todos os serviÃ§os necessÃ¡rio ao funcionamento do ExpressoLivre ou lhe permitirÃ¡ escolher quais serviÃ§os serÃ£o instalados e configurados. Esta Ãºltima alternativa Ã© interessante para ambientes grandes, onde os serviÃ§os sÃ£o instalados e configurados em mÃ¡quinas distintas.
+O script de instalacao lhe permitira escolher entre instalar e configurar automaticamente todos os servicos necessario ao funcionamento do ExpressoLivre ou lhe permitira escolher quais servicos serao instalados e configurados. Esta Ultima alternativa e interessante para ambientes grandes, onde os servicos sao instalados e configurados em maquinas distintas. 
 
-As informaÃ§Ãµes de senha, domÃ­nio e organizaÃ§Ã£o serÃ£o requisitadas de acordo com o(s) serviÃ§o(s) selecionado(s).
+As informacoes de senha, dominio e organizacao serao requisitadas de acordo com o(s) servico(s) selecionado(s). 
 
-A equipe ExpressoLivre nÃ£o se responsabiliza por danos ocasionados pelo uso deste instalador ou mesmo pelo prÃ³prio ExpressoLivre.
-VocÃª deseja prosseguir, por sua conta e risco, a instalaÃ§Ã£o ExpressoLivre?'
+A equipe ExpressoLivre nao se responsabiliza por danos ocasionados pelo uso deste instalador ou mesmo pelo proprio ExpressoLivre. 
+Voce deseja prosseguir, por sua conta e risco, a instalacao ExpressoLivre?' 
 
-# Se o usuario escolher "nao", serÃ¡ retornado 1 e consequentemente o script serÃ¡ encerrado.
+# Se o usuario escolher "nao", sera retornado 1 e consequentemente o script sera encerrado. 
 dialog --backtitle "$BACKTITLE" --cr-wrap --yesno "$INTRO" 18 80 || exit 0
 
 # Inicia a escolha/instalacao e configuracao dos servicos nessarios ao ExpressoLivre
 SERVICOS=$( dialog --backtitle "$BACKTITLE" --stdout --separate-output \
-	--checklist 'Por favor, selecione quais serviÃ§os serÃ£o instalados neste sistema operacional:' 14 75 14 \
-	http 'Servidor http (apache) juntamente com os mÃ³dulos do PHP5' on \
+	--checklist 'Por favor, selecione quais servicos serao instalados neste sistema operacional:' 14 75 14 \ 
+ 	http 'Servidor http (apache) juntamente com os modulos do PHP5' on \ 
 	ldap 'Servidor ldap (openldap)' on \
 	bd 'Servidor de banco de dados (postgresql)' on \
@@ -102,3 +102,3 @@
 done
 
-dialog --backtitle "$BACKTITLE" --cr-wrap --msgbox "A comunidade do Expresso Livre agradece a sua participaÃ§Ã£o.\n\n\nEm caso de dÃºvidas, por favor, visite: http://www.expressolivre.org" 8 75
+dialog --backtitle "$BACKTITLE" --cr-wrap --msgbox "A comunidade do Expresso Livre agradece a sua participacao.\n\n\nEm caso de dÃÂºvidas, por favor, visite: http://www.expressolivre.org" 8 75
@@ -24,5 +24,5 @@
 #################################################################################################
 
-# TODO: Internacionalizar o script de instalaÃ§Ã£o:
+# TODO: Internacionalizar o script de instalacao:
 # http://www.linuxquestions.org/questions/programming-9/bash-script-how-to-get-locale-translations-802726/
 # http://tldp.org/LDP/abs/html/localization.html
